@@ -22,6 +22,7 @@
 #include "includes.h"
 
 TDNF_CLI_CONTEXT _context = {0};
+int nQuiet = 0;
 
 int main(int argc, char* argv[])
 {
@@ -31,6 +32,7 @@ int main(int argc, char* argv[])
     {
         {"autoerase",          TDNFCliAutoEraseCommand},
         {"autoremove",         TDNFCliAutoEraseCommand},
+        {"check",              TDNFCliCheckCommand},
         {"check-local",        TDNFCliCheckLocalCommand},
         {"check-update",       TDNFCliCheckUpdateCommand},
         {"clean",              TDNFCliCleanCommand},
@@ -61,6 +63,7 @@ int main(int argc, char* argv[])
     PTDNF pTdnf = NULL;
     int nFound = 0;
 
+    _context.pFnCheck = TDNFCliInvokeCheck;
     _context.pFnCheckLocal = TDNFCliInvokeCheckLocal;
     _context.pFnCheckUpdate = TDNFCliInvokeCheckUpdate;
     _context.pFnClean = TDNFCliInvokeClean;
@@ -80,6 +83,8 @@ int main(int argc, char* argv[])
     dwError = TDNFCliParseArgs(argc, argv, &pCmdArgs);
     BAIL_ON_CLI_ERROR(dwError);
 
+    nQuiet = pCmdArgs->nQuiet;
+
     //If --version, show version and exit
     if(pCmdArgs->nShowVersion)
     {
@@ -181,7 +186,7 @@ TDNFCliPrintError(
     {
         fprintf(stderr, "Error(%d) : %s\n", dwErrorCode, pszError);
     }
-    else
+    else if(!nQuiet)
     {
         fprintf(stderr, "%s\n", pszError);
     }
@@ -238,6 +243,14 @@ error:
     goto cleanup;
 }
 
+uint32_t
+TDNFCliInvokeCheck(
+    PTDNF_CLI_CONTEXT pContext
+    )
+{
+    return TDNFCheckPackages(pContext->hTdnf);
+}
+
 uint32_t
 TDNFCliInvokeCheckLocal(
     PTDNF_CLI_CONTEXT pContext,
