@@ -30,6 +30,11 @@ TDNFCliInvokeAlter(
     PTDNF_SOLVED_PKG_INFO pSolvedPkgInfo
     );
 
+uint32_t
+TDNFCliInvokeCheck(
+    PTDNF_CLI_CONTEXT pContext
+    );
+
 uint32_t
 TDNFCliInvokeCheckLocal(
     PTDNF_CLI_CONTEXT pContext,
